package com.ningdatech.pmapi.dashboard.controller;

import com.ningdatech.pmapi.dashboard.manage.ExpertStatisticsManage;
import com.ningdatech.pmapi.dashboard.manage.FundStatisticsManage;
import com.ningdatech.pmapi.dashboard.manage.MeetingStatisticsManage;
import com.ningdatech.pmapi.dashboard.manage.ProjectCostStatisticsManage;
import com.ningdatech.pmapi.dashboard.model.vo.*;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

/**
 * @author ZPF
 * @date 2023/11/25 上午10:36
 */
@RestController
@RequestMapping("/api/v1/statistics")
@Validated
@RequiredArgsConstructor
@Api(value = "StatisticsController", tags = "统计")
public class StatisticsController {

    private final FundStatisticsManage fundStatisticsManage;

    private final ExpertStatisticsManage expertStatisticsManage;

    private final MeetingStatisticsManage meetingStatisticsManage;

    private final ProjectCostStatisticsManage costStatisticsManage;

    @GetMapping("/fund")
    @ApiOperation("项目资金统计")
    public FundStatisticsVO fund(@RequestParam(required = false) Integer year) {
        return fundStatisticsManage.statistics(year);
    }

    @GetMapping("/expert")
    @ApiOperation("专家统计")
    public ExpertStatisticsVO expert(@RequestParam(required = false) Integer year) {
        return expertStatisticsManage.statistics(year);
    }

    @GetMapping("/meeting")
    @ApiOperation("评审会议统计")
    public MeetingStatisticsVO meeting(@RequestParam(required = false) Integer year) {
        return meetingStatisticsManage.statistics(year);
    }

    @GetMapping("/project-cost")
    @ApiOperation("项目成本统计")
    public CostStatisticsVO projectCost() {
        return costStatisticsManage.statistics();
    }
}
